"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterConditions = exports.executeFilterConditionTest = void 0;
const booleanFilterCondition_js_1 = require("./booleanFilterCondition.js");
const collectionSearchFilterCondition_js_1 = require("./collectionSearchFilterCondition.js");
const numberFilterCondition_js_1 = require("./numberFilterCondition.js");
const stringFilterCondition_js_1 = require("./stringFilterCondition.js");
const filterUtilities_js_1 = require("./filterUtilities.js");
const filterConditionProcesses_js_1 = require("./filterConditionProcesses.js");
const dateFilterCondition_js_1 = require("./dateFilterCondition.js");
const objectFilterCondition_js_1 = require("./objectFilterCondition.js");
/** Execute mapped condition (per field type) for each cell in the grid */
exports.executeFilterConditionTest = ((options, parsedSearchTerms) => {
    // when using a multi-select ('IN' operator) we will not use the field type but instead go directly with a collection search
    if ((0, filterUtilities_js_1.isCollectionOperator)(options.operator)) {
        return (0, collectionSearchFilterCondition_js_1.executeCollectionSearchFilterCondition)(options);
    }
    // From a more specific field type (dateIso, dateEuro, text, readonly, ...), get the more generalized type (boolean, date, number, object, text)
    const generalizedType = (0, filterConditionProcesses_js_1.getVarTypeOfByColumnFieldType)(options.filterSearchType || options.fieldType);
    // execute the mapped type, or default to String condition check
    switch (generalizedType) {
        case 'boolean':
            // the parsedSearchTerms should be single value (result came from getFilterParsedBoolean() method)
            return (0, booleanFilterCondition_js_1.executeBooleanFilterCondition)(options, parsedSearchTerms);
        case 'date':
            return (0, dateFilterCondition_js_1.executeDateFilterCondition)(options, (parsedSearchTerms || []));
        case 'number':
            return (0, numberFilterCondition_js_1.executeNumberFilterCondition)(options, (parsedSearchTerms || []));
        case 'object':
            // the parsedSearchTerms should be single value (result came from getFilterParsedObjectResult() method)
            return (0, objectFilterCondition_js_1.executeObjectFilterCondition)(options, parsedSearchTerms);
        case 'string':
        default:
            // the parsedSearchTerms should be single value (result came from getFilterParsedText() method)
            return (0, stringFilterCondition_js_1.executeStringFilterCondition)(options, (parsedSearchTerms || []));
    }
});
exports.FilterConditions = {
    executeFilterConditionTest: exports.executeFilterConditionTest,
    booleanFilter: booleanFilterCondition_js_1.executeBooleanFilterCondition,
    collectionSearchFilter: collectionSearchFilterCondition_js_1.executeCollectionSearchFilterCondition,
    numberFilter: numberFilterCondition_js_1.executeNumberFilterCondition,
    stringFilter: stringFilterCondition_js_1.executeStringFilterCondition,
};
//# sourceMappingURL=filterConditions.index.js.map