"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Formatters = void 0;
const fieldType_enum_js_1 = require("../enums/fieldType.enum.js");
const formatterUtilities_js_1 = require("./formatterUtilities.js");
const utilities_js_1 = require("../services/utilities.js");
const arrayObjectToCsvFormatter_js_1 = require("./arrayObjectToCsvFormatter.js");
const arrayToCsvFormatter_js_1 = require("./arrayToCsvFormatter.js");
const checkmarkMaterialFormatter_js_1 = require("./checkmarkMaterialFormatter.js");
const currencyFormatter_js_1 = require("./currencyFormatter.js");
const collectionFormatter_js_1 = require("./collectionFormatter.js");
const collectionEditorFormatter_js_1 = require("./collectionEditorFormatter.js");
const complexObjectFormatter_js_1 = require("./complexObjectFormatter.js");
const decimalFormatter_js_1 = require("./decimalFormatter.js");
const dollarColoredBoldFormatter_js_1 = require("./dollarColoredBoldFormatter.js");
const dollarColoredFormatter_js_1 = require("./dollarColoredFormatter.js");
const dollarFormatter_js_1 = require("./dollarFormatter.js");
const hyperlinkFormatter_js_1 = require("./hyperlinkFormatter.js");
const iconBooleanFormatter_js_1 = require("./iconBooleanFormatter.js");
const iconFormatter_js_1 = require("./iconFormatter.js");
const maskFormatter_js_1 = require("./maskFormatter.js");
const multipleFormatter_js_1 = require("./multipleFormatter.js");
const percentFormatter_js_1 = require("./percentFormatter.js");
const percentCompleteBarFormatter_js_1 = require("./percentCompleteBarFormatter.js");
const percentCompleteBarWithTextFormatter_js_1 = require("./percentCompleteBarWithTextFormatter.js");
const percentCompleteFormatter_js_1 = require("./percentCompleteFormatter.js");
const percentSymbolFormatter_js_1 = require("./percentSymbolFormatter.js");
const progressBarFormatter_js_1 = require("./progressBarFormatter.js");
const translateFormatter_js_1 = require("./translateFormatter.js");
const treeExportFormatter_js_1 = require("./treeExportFormatter.js");
const treeFormatter_js_1 = require("./treeFormatter.js");
const treeParseTotalsFormatter_js_1 = require("./treeParseTotalsFormatter.js");
const translateBooleanFormatter_js_1 = require("./translateBooleanFormatter.js");
/** Provides a list of different Formatters that will change the cell value displayed in the UI */
const allFormatters = {
    arrayObjectToCsv: arrayObjectToCsvFormatter_js_1.arrayObjectToCsvFormatter,
    arrayToCsv: arrayToCsvFormatter_js_1.arrayToCsvFormatter,
    checkmarkMaterial: checkmarkMaterialFormatter_js_1.checkmarkMaterialFormatter,
    complex: complexObjectFormatter_js_1.complexObjectFormatter,
    complexObject: complexObjectFormatter_js_1.complexObjectFormatter,
    collection: collectionFormatter_js_1.collectionFormatter,
    collectionEditor: collectionEditorFormatter_js_1.collectionEditorFormatter,
    currency: currencyFormatter_js_1.currencyFormatter,
    date: (0, formatterUtilities_js_1.getBaseDateFormatter)(),
    // --
    // add all the date Formatters dynamically below
    decimal: decimalFormatter_js_1.decimalFormatter,
    dollar: dollarFormatter_js_1.dollarFormatter,
    dollarColored: dollarColoredFormatter_js_1.dollarColoredFormatter,
    dollarColoredBold: dollarColoredBoldFormatter_js_1.dollarColoredBoldFormatter,
    hyperlink: hyperlinkFormatter_js_1.hyperlinkFormatter,
    icon: iconFormatter_js_1.iconFormatter,
    iconBoolean: iconBooleanFormatter_js_1.iconBooleanFormatter,
    mask: maskFormatter_js_1.maskFormatter,
    multiple: multipleFormatter_js_1.multipleFormatter,
    percent: percentFormatter_js_1.percentFormatter,
    percentComplete: percentCompleteFormatter_js_1.percentCompleteFormatter,
    percentCompleteBar: percentCompleteBarFormatter_js_1.percentCompleteBarFormatter,
    percentCompleteBarWithText: percentCompleteBarWithTextFormatter_js_1.percentCompleteBarWithTextFormatter,
    percentSymbol: percentSymbolFormatter_js_1.percentSymbolFormatter,
    progressBar: progressBarFormatter_js_1.progressBarFormatter,
    translate: translateFormatter_js_1.translateFormatter,
    translateBoolean: translateBooleanFormatter_js_1.translateBooleanFormatter,
    tree: treeFormatter_js_1.treeFormatter,
    treeParseTotals: treeParseTotalsFormatter_js_1.treeParseTotalsFormatter,
    treeExport: treeExportFormatter_js_1.treeExportFormatter,
};
// add date Formatters dynamically but exclude "FieldType.date" since that one was created above
// and it has a different implementation
(0, utilities_js_1.getAllDateFieldTypes)().forEach((dateType) => {
    const fieldType = fieldType_enum_js_1.FieldType[dateType];
    if (fieldType && fieldType !== fieldType_enum_js_1.FieldType.date) {
        allFormatters[dateType] = (0, formatterUtilities_js_1.getAssociatedDateFormatter)(fieldType, dateType);
    }
});
/**
 * All available Formatters, including static and dynamically added date formatters.
 *
 * - Static: see IFormatters interface
 * - Dynamic: all date field types (see {@link getAllDateFieldTypes})
 */
exports.Formatters = allFormatters;
//# sourceMappingURL=formatters.index.js.map