"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SortComparers = void 0;
const fieldType_enum_js_1 = require("../enums/fieldType.enum.js");
const dateUtilities_js_1 = require("./dateUtilities.js");
const utilities_js_1 = require("../services/utilities.js");
const booleanSortComparer_js_1 = require("./booleanSortComparer.js");
const numericSortComparer_js_1 = require("./numericSortComparer.js");
const objectStringSortComparer_js_1 = require("./objectStringSortComparer.js");
const stringSortComparer_js_1 = require("./stringSortComparer.js");
// export the Sort Utilities so they could be used by others
__exportStar(require("./sortUtilities.js"), exports);
/**
 * Builds a map of all available SortComparers, including date comparers.
 * @returns {ISortComparers} All sort comparers, keyed by type.
 */
function buildAllSortComparers() {
    const comparers = {
        boolean: booleanSortComparer_js_1.booleanSortComparer,
        numeric: numericSortComparer_js_1.numericSortComparer,
        objectString: objectStringSortComparer_js_1.objectStringSortComparer,
        string: stringSortComparer_js_1.stringSortComparer,
    };
    // Dynamically add date comparers based on available FieldTypes, doing it this way to keep smaller bundle size
    (0, utilities_js_1.getAllDateFieldTypes)().forEach((dateType) => {
        const fieldType = fieldType_enum_js_1.FieldType[dateType];
        if (fieldType) {
            comparers[dateType] = (0, dateUtilities_js_1.getAssociatedDateSortComparer)(fieldType);
        }
    });
    return comparers;
}
/**
 * All available SortComparers, including static and dynamically added date comparers.
 *
 * - Static: boolean, numeric, objectString, string
 * - Dynamic: all date field types (see {@link getAllDateFieldTypes})
 */
exports.SortComparers = buildAllSortComparers();
//# sourceMappingURL=sortComparers.index.js.map